bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGammaISO.delete
==================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGammaISO.delete